==> web-audio-engine-0.10.2.tgz: package/lib/api/AudioBufferSourceNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioNode = require("./AudioNode");
var AudioParam = require("./AudioParam");

var AudioBufferSourceNode = function (_AudioNode) {
  _inherits(AudioBufferSourceNode, _AudioNode);

  function AudioBufferSourceNode(context, opts) {
    _classCallCheck(this, AudioBufferSourceNode);

    var _this = _possibleConstructorReturn(this, (AudioBufferSourceNode.__proto__ || Object.getPrototypeOf(AudioBufferSourceNode)).call(this, context));

    _this._impl = new impl.AudioBufferSourceNode(context._impl, opts);
    _this._impl.$playbackRate = new AudioParam(context, _this._impl.getPlaybackRate());
    _this._impl.$detune = new AudioParam(context, _this._impl.getDetune());
    _this._impl.$buffer = null;
    _this._impl.$onended = null;
    return _this;
  }

  _createClass(AudioBufferSourceNode, [{
    key: "start",
    value: function start(when, offset, duration) {
      this._impl.start(when, offset, duration);
    }
  }, {
    key: "stop",
    value: function stop(when) {
      this._impl.stop(when);
    }
  }, {
    key: "buffer",
    get: function get() {
      return this._impl.$buffer;
    },
    set: function set(value) {
      this._impl.$buffer = value;
      this._impl.setBuffer(value);
    }
  }, {
    key: "playbackRate",
    get: function get() {
      return this._impl.$playbackRate;
    }
  }, {
    key: "detune",
    get: function get() {
      return this._impl.$detune;
    }
  }, {
    key: "loop",
    get: function get() {
      return this._impl.getLoop();
    },
    set: function set(value) {
      this._impl.setLoop(value);
    }
  }, {
    key: "loopStart",
    get: function get() {
      return this._impl.getLoopStart();
    },
    set: function set(value) {
      this._impl.setLoopStart(value);
    }
  }, {
    key: "loopEnd",
    get: function get() {
      return this._impl.getLoopEnd();
    },
    set: function set(value) {
      this._impl.setLoopEnd(value);
    }
  }, {
    key: "onended",
    get: function get() {
      return this._impl.$onended;
    },
    set: function set(callback) {
      this._impl.replaceEventListener("ended", this._impl.$onended, callback);
      this._impl.$onended = callback;
    }
  }]);

  return AudioBufferSourceNode;
}(AudioNode);

module.exports = AudioBufferSourceNode;

==> web-audio-engine-0.13.1.tgz: package/lib/api/AudioBufferSourceNode.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var impl = require("../impl");
var AudioScheduledSourceNode = require("./AudioScheduledSourceNode");
var AudioParam = require("./AudioParam");

var AudioBufferSourceNode = function (_AudioScheduledSource) {
  _inherits(AudioBufferSourceNode, _AudioScheduledSource);

  function AudioBufferSourceNode(context, opts) {
    _classCallCheck(this, AudioBufferSourceNode);

    var _this = _possibleConstructorReturn(this, (AudioBufferSourceNode.__proto__ || Object.getPrototypeOf(AudioBufferSourceNode)).call(this, context));

    _this._impl = new impl.AudioBufferSourceNode(context._impl, opts);
    _this._impl.$playbackRate = new AudioParam(context, _this._impl.getPlaybackRate());
    _this._impl.$detune = new AudioParam(context, _this._impl.getDetune());
    _this._impl.$buffer = null;
    _this._impl.$onended = null;

    if (opts && opts.buffer) {
      _this.buffer = opts.buffer;
    }
    return _this;
  }

  _createClass(AudioBufferSourceNode, [{
    key: "start",
    value: function start(when, offset, duration) {
      this._impl.start(when, offset, duration);
    }
  }, {
    key: "buffer",
    get: function get() {
      return this._impl.$buffer;
    },
    set: function set(value) {
      this._impl.$buffer = value;
      this._impl.setBuffer(value);
    }
  }, {
    key: "playbackRate",
    get: function get() {
      return this._impl.$playbackRate;
    }
  }, {
    key: "detune",
    get: function get() {
      return this._impl.$detune;
    }
  }, {
    key: "loop",
    get: function get() {
      return this._impl.getLoop();
    },
    set: function set(value) {
      this._impl.setLoop(value);
    }
  }, {
    key: "loopStart",
    get: function get() {
      return this._impl.getLoopStart();
    },
    set: function set(value) {
      this._impl.setLoopStart(value);
    }
  }, {
    key: "loopEnd",
    get: function get() {
      return this._impl.getLoopEnd();
    },
    set: function set(value) {
      this._impl.setLoopEnd(value);
    }
  }]);

  return AudioBufferSourceNode;
}(AudioScheduledSourceNode);

module.exports = AudioBufferSourceNode;
